%This m-file is used for calculation and investigation of the expected total return 
%of zero bonds with maturity=lag at future time s
clear all;

load ER_X_Y_at_t.mat
%Current exchange rate
ER_X_Y=ER_X_Y_at_t(3);
%Current time
t=ER_X_Y_at_t(1);
lasttime=ER_X_Y_at_t(2);

lag=0.01;

%COUNTRY X
%COUNTRY X with following values
load ValX.mat
r=ValX(1);
kappa=ValX(2);
theta=ValX(3);
sigma=ValX(4);
lambda=ValX(5);
gamma=((kappa+lambda)^2+2*(sigma^2))^0.5;
%Long term value of the yield
Rl=(2*kappa*theta)/(gamma+kappa+lambda);
%Critical value, which determines whether or not the term structure is humped
Rg=(kappa*theta)/(kappa+lambda);
phi1=gamma;
phi2=(kappa+lambda+gamma)*0.5;
phi3=(2*kappa*theta)/(sigma^2);

%These values can be chosen constant, cause we only investigate bonds with maturity=lag
N=phi2*(exp(phi1*(lag))-1)+phi1;    
At=(phi1*exp(phi2*(lag))/N)^phi3;
Bt=(exp(phi1*(lag))-1)/N;

%Value in the long-run
Yl=(1/At)*((2*kappa/sigma^2)/((2*kappa/sigma^2)-Bt))^(2*kappa*theta/sigma^2)-1

%This part calculates the expectation of the TR when reinvesting every period
%The yield for a zero bond with time to maturity = lag at the current time t=0
if At~=0
    Rrt=(-log(At)+r*Bt)/(lag);
else
    Rrt=NaN;
end

%The expected total return for a zero bond with maturity=0.01 at current time t
%can be calculated as follows:
RTR(1)=exp(Rrt*lag)-1;
i=1;
for s=lag+t:lag:lasttime-0.01
    i=i+1;    
    c=(2.*kappa)./(sigma.^2.*(1-exp(-kappa.*(s-t))));
    u=c.*r.*exp(-kappa.*(s-t));
    q=(2.*kappa.*theta)./(sigma.^2)-1;
    RTR(i)=(1/At)*(c/(c-Bt))^(q+1)*exp((u*Bt)/(c-Bt))-1;
end

visu2=figure;
plot(t:lag:lasttime-0.01,RTR,'b');hold on;

clear kappa theta sigma lambda gamma phi1 phi2 phi3 r Rrt i RTR s c u q Yl At Bt;
  


%COUNTRY Y
%COUNTRY Y with following values
load ValY.mat
r=ValY(1);
kappa=ValY(2);
theta=ValY(3);
sigma=ValY(4);
lambda=ValY(5);
gamma=((kappa+lambda)^2+2*(sigma^2))^0.5;
%Long term value of the yield
Rl=(2*kappa*theta)/(gamma+kappa+lambda);
%Critical value, which determines whether or not the term structure is humped
Rg=(kappa*theta)/(kappa+lambda);
phi1=gamma;
phi2=(kappa+lambda+gamma)*0.5;
phi3=(2*kappa*theta)/(sigma^2);

%These values can be chosen constant, cause we only investigate bonds with maturity=lag
N=phi2*(exp(phi1*(lag))-1)+phi1;    
At=(phi1*exp(phi2*(lag))/N)^phi3;
Bt=(exp(phi1*(lag))-1)/N;

%Value in the long-run%
Yl=(1/At)*((2*kappa/sigma^2)/((2*kappa/sigma^2)-Bt))^(2*kappa*theta/sigma^2)-1

%This part calculates the expectation of the TR when reinvesting every period
%The yield for a zero bond with time to maturity = lag at the current time t=0
if At~=0
    Rrt=(-log(At)+r*Bt)/(lag);
else
    Rrt=NaN;
end

%The expected total return for a zero bond with maturity=0.01 at current time t
%can be calculated as follows:
RTR(1)=exp(Rrt*lag)-1;
i=1;
for s=lag+t:lag:lasttime-0.01
    i=i+1;    
    c=(2*kappa)/(sigma^2*(1-exp(-kappa*(s-t))));
    u=c*r*exp(-kappa*(s-t));
    q=(2*kappa*theta)/(sigma^2)-1;
    RTR(i)=(1/At)*(c/(c-Bt))^(q+1)*exp((u*Bt)/(c-Bt))-1;
end

plot(t:lag:lasttime-0.01,RTR,'r');
%title(['VAL: ',texlabel('r='),mat2str(ValY(1)),';',texlabel('kappa='),mat2str(ValY(2)),';',texlabel('theta='),mat2str(ValY(3)),';',texlabel('sigma='),mat2str(ValY(4)),';',texlabel('lambda='),mat2str(ValY(5))],'Fontsize', 11);legend([texlabel('Yl='),mat2str(Yl)],0);xlabel('Time s');ylabel('Expected future one period total return');grid on;
title(['VAL ONE: ',texlabel('r='),mat2str(ValX(1)),';',texlabel('kappa='),mat2str(ValX(2)),';',texlabel('theta='),mat2str(ValX(3)),';',texlabel('sigma='),mat2str(ValX(4)),';',texlabel('lambda='),mat2str(ValX(5)),' VAL TWO: ',texlabel('r='),mat2str(ValY(1)),';',texlabel('kappa='),mat2str(ValY(2)),';',texlabel('theta='),mat2str(ValY(3)),';',texlabel('sigma='),mat2str(ValY(4)),';',texlabel('lambda='),mat2str(ValY(5))],'Fontsize', 11);legend([texlabel('sigma^2='),mat2str(ValX(4)^2)],[texlabel('sigma^2='),mat2str(ValY(4)^2)],0);xlabel('Time s');ylabel('Expected future one period total return');grid on;


%SAVING OF PLOT with counting number i
i=12;
saveas(visu2,['Exp1TR',mat2str(i),'.eps']);
saveas(visu2,['Exp1TR',mat2str(i),'.fig']);

clear all;

